// 240430
/*The truth of culture is that it spreads and evolves freely.
Released into the Public Domain / CC0. Free to access, study, remix and reuse.
Attribution is appreciated, but not required.*/

(
s.options.sampleRate = 11025;
s.boot;
)

(
//Out Buffer
~soundLength = 8;

b.free;
b = Buffer.alloc(s, s.sampleRate * ~soundLength, 1);

)

(

// PDSTR //
SynthDef(\PDSTR, {|freq=440, detune=1.7|
	var audio;

	audio = Saw.ar(
		freq: [freq - (detune*1),
			freq - (detune*0.5),
			freq - detune,
			freq,
			freq + detune,
			freq + (detune*0.5),
			freq + (detune*1)
	],
	mul: 1.0,
	add: 0.0
	);

	audio = LPF.ar(audio,800);

	audio = audio * EnvGen.ar(Env.perc(attackTime: 3,releaseTime: 4, curve: -5.0),doneAction: 2);

	audio = Splay.ar(audio,spread: 1,level: 0.2, center: 0.0);

	audio = Compander.ar(
		in: audio,
		control: audio,
		thresh: 0.5,
		slopeBelow: 1.0,
		slopeAbove: 1.0,
		clampTime: 0.01,
		relaxTime: 0.1,
		mul: 1.0,
		add: 0.0
	);

	RecordBuf.ar(audio[0],b);
 	Out.ar(0, audio);

}).add;

// BKICK //
SynthDef(\BKICK, {|freq=440|
	var audio;

	audio = SinOsc.ar(freq: freq + (freq * 1.5 * Env.perc(0.01,0.01,curve: -8.0).ar),
		phase: 0.0,
		mul: 1.0,
		add: 0.0
	);

	audio = audio * EnvGen.ar(Env.perc(attackTime: 0.01,releaseTime: 0.4, curve: -6.0),doneAction: 2);

	audio = audio;

	audio = Splay.ar(audio,
		spread: 1,
		level: 0.2,
		center: 0.0,
		levelComp: true
	);

	RecordBuf.ar(audio[0],b);
	Out.ar(0, audio);

}).add;


)

(
// PTING //

SynthDef(\PTING, {|freq=440|
	var audio, ping;

	//Generators
	audio = WhiteNoise.ar();
	audio = audio + SinOsc.ar(XLine.ar(1400,60,~soundLength*0.15,0.4));

	ping = SinOsc.ar(XLine.ar(8000,3000,~soundLength*0.05)) * EnvGen.ar(Env.perc(0.01,~soundLength*0.5));
	audio = (audio * 0.6) + ping;

	//Envelope and Filters
	audio = HPF.ar(audio, Line.ar(300,800,~soundLength));
	audio = audio * EnvGen.ar(Env.perc(0.01,~soundLength*0.6),doneAction: 2);

	//Center the sound for testing
	audio = Splay.ar(audio,
		spread: 1,
		level: 0.5,
		center: 0.0,
		levelComp: true
	);

	//Buffer Recording and playback
	RecordBuf.ar(audio[0],b);
	Out.ar(0, audio);

}).play();

)

(
// SNRCP //

SynthDef(\SNRCP, {
	var audio, length;

	length = 0.5;

	//Generators
	audio = WhiteNoise.ar();
	audio = audio + SinOsc.ar(XLine.ar(1400,60,length*0.15,0.4));

	//Envelope and Filters
	audio = HPF.ar(audio, Line.ar(300,800,length));
	audio = audio * EnvGen.ar(Env.perc(0.01,length*0.6),doneAction: 2);

	//Center the sound for testing
	audio = Splay.ar(audio,
		spread: 1,
		level: 0.5,
		center: 0.0,
		levelComp: true
	);

	//Buffer Recording and playback
	RecordBuf.ar(audio[0],b);
	Out.ar(0, audio);

}).play();

)

(
// MALTB / PLUCK //

SynthDef(\MALTB, {
	var audio, freq, length, delayWindow;

	//Frequency
	freq = 72.midicps;
	length = 1;

	//Generators
	audio = Klang.ar(`[
		[freq * 3, freq * 4, freq * 5, freq * 6, freq * 7],
		[1.0, 0.6, 0.4, 0.2, 0.1]],
	freqscale: 1.0,
	freqoffset: 0.0
	);

	audio = (audio * 0.7) + Pulse.ar(Line.ar(freq * 5, freq, length * 0.03), 0.5);

	audio = audio * EnvGen.ar(Env.perc(0.01,length * 0.3),doneAction: 0);

	audio = audio + DelayC.ar(
		in: audio,
		maxdelaytime: length/4,
		delaytime: length/4,
		mul: 0.2
	);

	//Unload the synth
	delayWindow = EnvGen.ar(Env.perc(0.01,length * 8),doneAction: 0);

	//Center the sound for testing
	audio = Splay.ar(audio,
		spread: 1,
		level: 0.2,
		center: 0.0,
		levelComp: true
	);

	//Buffer Recording and playback
	RecordBuf.ar(audio[0],b);
	Out.ar(0, audio);

}).play();

)

(
b.write(headerFormat: "WAV", sampleFormat: "int16", numFrames: b.numFrames, startFrame: 0, leaveOpen: false);
)


